User prompt
Make score chart
User prompt
Make enemies disappear when shot
User prompt
Increase player speed by a bunch
User prompt
Make player move faster
User prompt
Make enemy lives decrease by 1 live when hit
User prompt
Make enemies at top of game
User prompt
Delete lightblue block
User prompt
Delete light blue block
User prompt
Please fix the bug: 'ReferenceError: target is not defined' in or related to this line: 'if (fire.intersects(target)) {' Line Number: 136
User prompt
Make blue blocks bad guys
User prompt
Please fix the bug: 'ReferenceError: player is not defined' in or related to this line: 'if (player.intersects(target)) {' Line Number: 118
User prompt
Please fix the bug: 'Uncaught ReferenceError: player is not defined' in or related to this line: 'fire.x = player.x;' Line Number: 97
User prompt
Make a rocket that shoots red fiery bullets
User prompt
Make player have 3 lives
User prompt
Make joystick for player
User prompt
Make a fire breathing monster
Initial prompt
Creeper99iscool
===================================================================
--- original.js
+++ change.js
@@ -1,7 +1,18 @@
/****
* Classes
****/
+var FieryBullet = Container.expand(function () {
+ var self = Container.call(this);
+ var fieryBulletGraphics = self.attachAsset('fieryBullet', {
+ anchorX: 0.5,
+ anchorY: 0.5
+ });
+ self.speed = 5;
+ self.update = function () {
+ self.y -= self.speed;
+ };
+});
// Define the Fire class
var Fire = Container.expand(function () {
var self = Container.call(this);
var fireGraphics = self.attachAsset('fire', {
@@ -26,17 +37,17 @@
};
});
//<Assets used in the game will automatically appear here>
// Define the Player class
-var Player = Container.expand(function () {
+var Rocket = Container.expand(function () {
var self = Container.call(this);
- var playerGraphics = self.attachAsset('player', {
+ var rocketGraphics = self.attachAsset('rocket', {
anchorX: 0.5,
anchorY: 0.5
});
self.speed = 10;
self.update = function () {
// Player update logic
};
self.move = function (x, y) {
self.x = x;
self.y = y;
@@ -64,12 +75,13 @@
/****
* Game Code
****/
// Initialize player, target, fire and joystick
-var player = game.addChild(new Player());
-player.x = 2048 / 2;
-player.y = 2732 - 200;
-player.lives = 3; // Initialize player with 3 lives
+var rocket = game.addChild(new Rocket());
+rocket.x = 2048 / 2;
+rocket.y = 2732 - 200;
+rocket.lives = 3; // Initialize rocket with 3 lives
+var fieryBullets = [];
var target = game.addChild(new Target());
target.x = Math.random() * 2048;
target.y = Math.random() * 2732;
var fire = game.addChild(new Fire());
@@ -80,15 +92,18 @@
joystick.y = 2732 - 200;
// Handle player movement and fire breathing
game.down = function (x, y, obj) {
joystick.move(x, y);
- var dx = joystick.x - player.x;
- var dy = joystick.y - player.y;
+ var dx = joystick.x - rocket.x;
+ var dy = joystick.y - rocket.y;
var angle = Math.atan2(dy, dx);
- player.x += Math.cos(angle) * player.speed;
- player.y += Math.sin(angle) * player.speed;
- fire.x = player.x;
- fire.y = player.y;
+ rocket.x += Math.cos(angle) * rocket.speed;
+ rocket.y += Math.sin(angle) * rocket.speed;
+ var newFieryBullet = new FieryBullet();
+ newFieryBullet.x = rocket.x;
+ newFieryBullet.y = rocket.y;
+ fieryBullets.push(newFieryBullet);
+ game.addChild(newFieryBullet);
};
// Check for win condition and player lives
game.update = function () {
@@ -26,17 +37,17 @@
self.speed = 10;
self.update = function () {
- // Player update logic
+ // Rocket update logic
};
self.move = function (x, y) {
if (player.intersects(target)) {
Red fiery bullet. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
Monster. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
Rocket. Single Game Texture. In-Game asset. 2d. Blank background. High contrast. No shadows.
Space scene that would be good for an app background. Single Game Texture. In-Game asset. 3d. Blank background. High contrast. No shadows.
Bullet dropping downward. Single Game Texture. In-Game asset. 3D. Blank background. High contrast. No shadows.